@@ -1,33 +1,90 @@
+// MIT http://rem.mit-license.org
+
+function trim(c) {
+    let ctx = c.getContext('2d'),
+        copy = document.createElement('canvas').getContext('2d'),
+        pixels = ctx.getImageData(0, 0, c.width, c.height),
+        l = pixels.data.length,
+        i,
+        bound = {
+            top: null,
+            left: null,
+            right: null,
+            bottom: null
+        },
+        x, y;
+
+    for (i = 0; i < l; i += 4) {
+        if (pixels.data[i+3] !== 0) {
+            x = (i / 4) % c.width;
+            y = ~~((i / 4) / c.width);
+
+            if (bound.top === null) {
+                bound.top = y;
+            }
+
+            if (bound.left === null) {
+                bound.left = x;
+            } else if (x < bound.left) {
+                bound.left = x;
+            }
+
+            if (bound.right === null) {
+                bound.right = x;
+            } else if (bound.right < x) {
+                bound.right = x;
+            }
+
+            if (bound.bottom === null) {
+                bound.bottom = y;
+            } else if (bound.bottom < y) {
+                bound.bottom = y;
+            }
+        }
+    }
+
+    let trimHeight = bound.bottom - bound.top,
+        trimWidth = bound.right - bound.left,
+        trimmed = ctx.getImageData(bound.left, bound.top, trimWidth, trimHeight);
+
+    copy.canvas.width = trimWidth;
+    copy.canvas.height = trimHeight;
+    copy.putImageData(trimmed, 0, 0);
+
+    // open new window with trimmed image:
+    return copy.canvas;
+}
+
 window.addEventListener("load", () => {
     document.querySelectorAll(".signature-field")
         .forEach((field) => {
-            let canvas = field.querySelector("canvas");
-            let input = field.querySelector("input");
+            const id = field.getAttribute("data-signature-field-id");
+            let canvas = document.getElementById(`signature-field-${id}__canvas`);
+            if (canvas.parentElement) {
+                canvas.parentElement.style.width = "100vw";
+                canvas.parentElement.style.maxWidth = "100vw";
+                canvas.parentElement.style.height = "100vh";
+                canvas.parentElement.style.maxHeight = "100vh";
+                canvas.parentElement.style.overflow = "none";
+                canvas.parentElement.style.borderRadius = "0";
+            }
+            let input = document.getElementById(`signature-field-${id}__input`);
             let ctx = canvas.getContext("2d");
 
             const dpr = window.devicePixelRatio || 1;
 
-            const rect = canvas.getBoundingClientRect();
+            //const rect = canvas.getBoundingClientRect();
             // Give the canvas pixel dimensions of their CSS
             // size * the device pixel ratio.
-            canvas.width = rect.width * dpr;
-            canvas.height = rect.height * dpr;
 
-            ctx.lineWidth = 4 * dpr;
-            ctx.lineCap = "round";
-            ctx.lineJoin = "round";
-            ctx.imageSmoothingEnabled = true;
+            canvas.width = window.innerWidth * dpr;
+            canvas.height = window.innerHeight * dpr;
 
-            ctx.strokeStyle = getComputedStyle(document.body)
-                .getPropertyValue('--color-text');
+            window.addEventListener("resize", () => {
+                canvas.width = window.innerWidth * dpr;
+                canvas.height = window.innerHeight * dpr;
 
-            console.log(ctx.strokeStyle);
-
-            window.matchMedia("(prefers-color-scheme: dark)")
-                .addEventListener("change", e => {
-                    ctx.strokeStyle = getComputedStyle(document.body)
-                        .getPropertyValue('--color-text');
-                });
+            });
 
             let drawing = false;
             let mousePos = {
@@ -43,7 +100,7 @@ window.addEventListener("load", () => {
 
             canvas.addEventListener("mouseup", function (e) {
                 drawing = false;
-                input.value = canvas.toDataURL();
+                input.value = trim(canvas).toDataURL();
             }, false);
 
             canvas.addEventListener("mousemove", function (e) {
@@ -101,7 +158,13 @@ window.addEventListener("load", () => {
             }
 
             function renderCanvas() {
-                 if (drawing) {
+                ctx.strokeStyle = getComputedStyle(document.body)
+                    .getPropertyValue('--color-text');
+                if (drawing) {
+                    ctx.lineWidth = 4 * dpr;
+                    ctx.lineCap = "round";
+                    ctx.lineJoin = "round";
+                    ctx.imageSmoothingEnabled = true;
                     ctx.moveTo(lastPos.x, lastPos.y);
                     ctx.lineTo(mousePos.x, mousePos.y);
                     ctx.stroke();
